Products.zms.IZMSMetamodelProvider.IZMSMetamodelProvider

Package Products :: Package zms :: Module IZMSMetamodelProvider :: Class IZMSMetamodelProvider |
[frames] | no frames]

# Class IZMSMetamodelProvider

    zope.interface.Interface --+
                               |
                              IZMSMetamodelProvider

Instance Methods
`string` |
getMetaobjId(self, name) Returns id of meta-object specified by name. |
`list` |
getMetaobjIds(self, sort=False, excl_ids=[]) Returns list of all meta-ids in model. |
`dict` |
getMetaobj(self, id) Returns meta-object specified by meta-id. |
`list` |
getMetaobjAttrIds(self, meta_id, types=[]) Returns list of attribute-ids for meta-object specified by meta-id. |
`list` |
getMetaobjAttrs(self, meta_id, types=[]) Get all attributes for meta-object specified by meta-id. |
`dict` |
getMetaobjAttr(self, meta_id, key, sync=True) Get attribute for meta-object specified by attribute-id. |
`dict` |
getMetaobjAttrIdentifierId(self, meta_id) Get attribute-id of identifier for datatable specified by meta-id. |
`dict` |
notifyMetaobjAttrAboutValue(self, meta_id, key, value) Notify attribute for meta-object specified by attribute-id about value. |